@@ -113,6 +113,8 @@ void display_interfaces(lldpctl_conn_t *, struct writer *,
     struct cmd_env *, int, int);
 void display_interface(lldpctl_conn_t *, struct writer *, int,
     lldpctl_atom_t *, lldpctl_atom_t *, int, int);
+void display_local_chassis(lldpctl_conn_t *, struct writer *,
+    struct cmd_env *, int);
 void display_configuration(lldpctl_conn_t *, struct writer *);
 void display_interfaces_stats(lldpctl_conn_t *, struct writer *,
     struct cmd_env *);
