@@ -19,8 +19,15 @@
 #include <stdlib.h>
 #include <string.h>
 
+#if defined(__clang__)
+#pragma clang diagnostic push
+#pragma clang diagnostic ignored "-Wdocumentation"
+#endif
 #include <libxml/encoding.h>
 #include <libxml/xmlwriter.h>
+#if defined(__clang__)
+#pragma clang diagnostic pop
+#endif
 
 #include "writer.h"
 #include "../log.h"
