@@ -145,7 +145,7 @@ client_handle_set_configuration(struct lldpd *cfg, enum hmsg_type *type,
 	}
 	if (CHANGED_STR(c_hostname)) {
 		log_debug("rpc", "change system name to %s",
-		    config->c_hostname?config->c_hostname:"(NULL");
+		    config->c_hostname?config->c_hostname:"(NULL)");
 		free(cfg->g_config.c_hostname);
 		cfg->g_config.c_hostname = xstrdup(config->c_hostname);
 		levent_update_now(cfg);
@@ -162,6 +162,18 @@ client_handle_set_configuration(struct lldpd *cfg, enum hmsg_type *type,
 		cfg->g_config.c_promisc = config->c_promisc;
 		levent_update_now(cfg);
 	}
+	if (CHANGED(c_cap_advertise)) {
+		log_debug("rpc", "%s chassis capabilities advertisement",
+		    config->c_promisc?"enable":"disable");
+		cfg->g_config.c_cap_advertise = config->c_cap_advertise;
+		levent_update_now(cfg);
+	}
+	if (CHANGED(c_mgmt_advertise)) {
+		log_debug("rpc", "%s management addresses advertisement",
+		    config->c_promisc?"enable":"disable");
+		cfg->g_config.c_mgmt_advertise = config->c_mgmt_advertise;
+		levent_update_now(cfg);
+	}
 	if (CHANGED(c_bond_slave_src_mac_type)) {
 		if (config->c_bond_slave_src_mac_type >
 		    LLDP_BOND_SLAVE_SRC_MAC_TYPE_UNKNOWN &&
@@ -226,6 +238,27 @@ client_handle_get_interfaces(struct lldpd *cfg, enum hmsg_type *type,
 	return output_len;
 }
 
+/* Return the local chassis.
+   Input:  nothing.
+   Output: local chassis (lldpd_chassis)
+*/
+static ssize_t
+client_handle_get_local_chassis(struct lldpd *cfg, enum hmsg_type *type,
+    void *input, int input_len, void **output, int *subscribed)
+{
+    struct lldpd_chassis *chassis = LOCAL_CHASSIS(cfg);
+	ssize_t output_len;
+
+	log_debug("rpc", "client request the local chassis");
+	output_len = lldpd_chassis_serialize(chassis, output);
+	if (output_len <= 0) {
+		output_len = 0;
+		*type = NONE;
+	}
+
+	return output_len;
+}
+
 /* Return all available information related to an interface
    Input:  name of the interface (serialized)
    Output: Information about the interface (lldpd_hardware)
@@ -357,6 +390,28 @@ client_handle_set_port(struct lldpd *cfg, enum hmsg_type *type,
 				sizeof(struct lldpd_dot3_power));
 		    }
 #endif
+#ifdef ENABLE_CUSTOM
+		    if (set->custom_list_clear) {
+			    log_debug("rpc", "requested custom TLVs clear");
+			    lldpd_custom_list_cleanup(port);
+		    } else 
+		    if (set->custom) {
+			    struct lldpd_custom *custom;
+			    log_debug("rpc", "requested custom TLV add");
+			    if ((custom = malloc(sizeof(struct lldpd_custom)))) {
+				    memcpy(custom, set->custom, sizeof(struct lldpd_custom));
+				    if ((custom->oui_info = malloc(custom->oui_info_len))) {
+					    memcpy(custom->oui_info, set->custom->oui_info, custom->oui_info_len);
+					    TAILQ_INSERT_TAIL(&port->p_custom_list, custom, next);
+				    } else {
+					    free(custom);
+					    log_warn("rpc", "could not allocate memory for custom TLV info");
+				    }
+			    } else
+				    log_warn("rpc", "could not allocate memory for custom TLV");
+		    }
+#endif
+
 		    ret = 1;
 		    break;
 	    }
@@ -379,6 +434,12 @@ set_port_finished:
 #endif
 #ifdef ENABLE_DOT3
 	free(set->dot3_power);
+#endif
+#ifdef ENABLE_CUSTOM
+	if (set->custom) {
+		free(set->custom->oui_info);
+		free(set->custom);
+	}
 #endif
 	return 0;
 }
@@ -406,6 +467,7 @@ static struct client_handle client_handles[] = {
 	{ SET_CONFIG,		"Set configuration", client_handle_set_configuration },
 	{ GET_INTERFACES,	"Get interfaces",    client_handle_get_interfaces },
 	{ GET_INTERFACE,	"Get interface",     client_handle_get_interface },
+	{ GET_CHASSIS,		"Get local chassis", client_handle_get_local_chassis },
 	{ SET_PORT,		"Set port",          client_handle_set_port },
 	{ SUBSCRIBE,		"Subscribe",         client_handle_subscribe },
 	{ 0,			NULL } };
