@@ -25,13 +25,12 @@
 #include <unistd.h>
 #include <errno.h>
 #include <arpa/inet.h>
-#include <assert.h>
 
 static int
 cdp_send(struct lldpd *global,
 	 struct lldpd_hardware *hardware, int version)
 {
-	const char *platform = "Linux";
+	const char *platform = "Unknown";
 	struct lldpd_chassis *chassis;
 	struct lldpd_mgmt *mgmt;
 	struct lldpd_port *port;
@@ -199,6 +198,7 @@ cdp_send(struct lldpd *global,
 
 	/* Platform */
 	if (global && global->g_config.c_platform) platform = global->g_config.c_platform;
+
 	if (!(
 	      POKE_START_CDP_TLV(CDP_TLV_PLATFORM) &&
 	      POKE_BYTES(platform, strlen(platform)) &&
@@ -437,8 +437,13 @@ cdp_decode(struct lldpd *cfg, char *frame, int s,
 						mgmt = lldpd_alloc_mgmt(LLDPD_AF_IPV4, &addr, 
 									sizeof(struct in_addr), 0);
 						if (mgmt == NULL) {
-							assert(errno == ENOMEM);
-							log_warn("cdp", "unable to allocate memory for management address");
+							if (errno == ENOMEM)
+								log_warn("cdp",
+								    "unable to allocate memory for management address");
+							else
+								log_warn("cdp",
+								    "too large management address received on %s",
+								    hardware->h_ifname);
 							goto malformed;
 						}
 						TAILQ_INSERT_TAIL(&chassis->c_mgmt, mgmt, m_entries);
