@@ -107,7 +107,7 @@ typedef struct lldpctl_conn_t lldpctl_conn_t;
 /**
  * Callback function invoked to send data to lldpd.
  *
- * @param lldpctl   Handle to the connection to lldpd.
+ * @param conn      Handle to the connection to lldpd.
  * @param data      Bytes to be sent.
  * @param length    Length of provided data.
  * @param user_data Provided user data.
@@ -121,7 +121,7 @@ typedef ssize_t (*lldpctl_send_callback)(lldpctl_conn_t *conn,
 /**
  * Callback function invoked to receive data from lldpd.
  *
- * @param lldpctl   Handle to the connection to lldpd.
+ * @param conn      Handle to the connection to lldpd.
  * @param data      Buffer for receiving data
  * @param length    Maximum bytes we can receive
  * @param user_data Provided user data.
@@ -256,6 +256,17 @@ int lldpctl_release(lldpctl_conn_t *conn);
  */
 void lldpctl_log_callback(void (*cb)(int severity, const char *msg));
 
+/**
+ * Setup log level.
+ *
+ * By default, liblldpctl will only log warnings. The following function allows
+ * to increase verbosity. This function has no effect if callbacks are
+ * registered with the previous function.
+ *
+ * @param level    Level of verbosity (1 = warnings, 2 = info, 3 = debug).
+ */
+void lldpctl_log_level(int level);
+
 /**
  * Possible error codes for functions that return negative integers on
  * this purpose or for @c lldpctl_last_error().
@@ -528,6 +539,20 @@ lldpctl_atom_t *lldpctl_get_configuration(lldpctl_conn_t *conn);
  */
 lldpctl_atom_t *lldpctl_get_interfaces(lldpctl_conn_t *conn);
 
+/**
+ * Retrieve the information related to the local chassis.
+ *
+ * @param conn Previously allocated handler to a connection to lldpd.
+ * @return Atom related to the local chassis which may be used in subsequent functions.
+ *
+ * This function may have to do IO to get the information related to the local
+ * chassis. Depending on the IO mode, information may not be available right now
+ * and the function should be called again later. If @c NULL is returned, check
+ * what the last error is. If it is @c LLDPCTL_ERR_WOULDBLOCK, try again later
+ * (when more data is available).
+ */
+lldpctl_atom_t *lldpctl_get_local_chassis(lldpctl_conn_t *conn);
+
 /**
  * Retrieve the information related to a given interface.
  *
@@ -536,7 +561,7 @@ lldpctl_atom_t *lldpctl_get_interfaces(lldpctl_conn_t *conn);
  * @return Atom related to this port which may be used in subsequent functions.
  *
  * This functions may have to do IO to get the information related to the given
- * port. Depending on the IO mode, information may not be available tight now
+ * port. Depending on the IO mode, information may not be available right now
  * and the function should be called again later. If @c NULL is returned, check
  * what the last error is. If it is @c LLDPCTL_ERR_WOULDBLOCK, try again later
  * (when more data is available).
@@ -612,6 +637,8 @@ typedef enum {
 	lldpctl_k_config_fast_start_interval, /**< `(I,WO)` Start fast transmit interval */
 	lldpctl_k_config_ifdescr_update, /**< `(I,WO)` Enable or disable setting interface description */
 	lldpctl_k_config_iface_promisc,  /**< `(I,WO)` Enable or disable promiscuous mode on interfaces */
+	lldpctl_k_config_chassis_cap_advertise, /**< `(I,WO)` Enable or disable chassis capabilities advertisement */
+	lldpctl_k_config_chassis_mgmt_advertise, /**< `(I,WO)` Enable or disable management addresses advertisement */
 
 	lldpctl_k_interface_name = 1000, /**< `(S)` The interface name. */
 
@@ -629,6 +656,7 @@ typedef enum {
 	lldpctl_k_port_id,	   /**< `(BS,WO)` The ID of this port. */
 	lldpctl_k_port_descr,	   /**< `(S,WO)` The description of this port. */
 	lldpctl_k_port_hidden,	   /**< `(I)` Is this port hidden (or should it be displayed?)? */
+	lldpctl_k_port_chassis,	   /**< `(A)` Chassis associated to the port */
 
 	lldpctl_k_port_dot3_mfs = 1300,	   /**< `(I)` MFS */
 	lldpctl_k_port_dot3_aggregid,   /**< `(I)` Port aggregation ID */
@@ -727,6 +755,14 @@ typedef enum {
 	lldpctl_k_config_tx_hold, /**< `(I,WO)` Transmit hold interval. */
 	lldpctl_k_config_bond_slave_src_mac_type, /**< `(I,WO)` bond slave src mac type. */
 	lldpctl_k_config_lldp_portid_type, /**< `(I,WO)` LLDP PortID TLV Subtype */
+
+	lldpctl_k_custom_tlvs = 5000,		/**< `(AL)` custom TLVs */
+	lldpctl_k_custom_tlvs_clear,		/** `(I,WO)` clear list of custom TLVs */
+	lldpctl_k_custom_tlv,			/** `(AL,WO)` custom TLV **/
+	lldpctl_k_custom_tlv_oui,		/**< `(I,WO)` custom TLV Organizationally Unique Identifier. Default is 0 (3 bytes) */
+	lldpctl_k_custom_tlv_oui_subtype,	/**< `(I,WO)` custom TLV subtype. Default is 0 (1 byte) */
+	lldpctl_k_custom_tlv_oui_info_string,	/**< `(I,WO)` custom TLV Organizationally Unique Identifier Information String (up to 507 bytes) */
+
 } lldpctl_key_t;
 
 /**
