@@ -23,6 +23,10 @@
  * constants that are useful in the context of lldpd and its clients.
  */
 
+#define LLDP_TLV_ORG			127
+#define LLDP_TLV_ORG_OUI_LEN		3
+#define LLDP_TLV_ORG_OUI_INFO_MAXLEN	507
+
 /* Chassis ID subtype */
 #define LLDP_CHASSISID_SUBTYPE_CHASSIS	1
 #define LLDP_CHASSISID_SUBTYPE_IFALIAS	2
