@@ -15,7 +15,6 @@
  * OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
  */
 
-#define _GNU_SOURCE 1
 #define MARSHAL_EXPORT
 #include "marshal.h"
 
@@ -31,7 +30,11 @@
 #include "lldpd-structs.h"
 
 /* Stolen from CCAN */
-#define ALIGNOF(t) ((char *)(&((struct { char c; t _h; } *)0)->_h) - (char *)0)
+#if HAVE_ALIGNOF
+# define ALIGNOF(t) (__alignof__(t))
+#else
+# define ALIGNOF(t) ((sizeof(t) > 1)?((char *)(&((struct { char c; t _h; } *)0)->_h) - (char *)0):1)
+#endif
 
 /* A serialized object */
 struct marshal_serialized {
@@ -98,6 +101,7 @@ marshal_serialize_(struct marshal_info *mi, void *unserialized, void **input,
 	/* Handle special cases. */
 	size = mi->size;
 	if (!strcmp(mi->name, "null string"))
+		/* We know we can't be called with NULL */
 		size = strlen((char *)unserialized) + 1;
 	else if (!strcmp(mi->name, "fixed string"))
 		size = osize;
